package com.lantone.qc.kernel.catalogue.behospitalized;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.entity.PD;
import com.lantone.qc.pub.model.entity.Pacs;
import com.lantone.qc.pub.model.label.PacsLabel;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;


/**
 * @ClassName : BEH0490
 * @Description : 实验室检查未注明时间和地点
 * @Author : 胡敬
 * @Date: 2020-06-03 13:34
 */
@Component
public class BEH0490 extends QCCatalogue {
    @Override
    protected void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        if (inputInfo.getBeHospitalizedDoc() == null) {
            return;
        }

        PacsLabel pacsLabel = inputInfo.getBeHospitalizedDoc().getPacsLabel();
        if (pacsLabel == null || StringUtil.isBlank(pacsLabel.getText())) {
            return;
        }

        String pacsText = pacsLabel.getText();
        List<Pacs> pacses = pacsLabel.getPacses();
        for (Pacs pacs : pacses) {
            if (pacs.getName() == null && pacs.getPd() == null) {
                status.set("-1");
                return;
            } else {
                PD pd = pacs.getPd();
                if (pd == null) {
                    continue;
                }
                String name = pd.getName();
                int timeIndex = pacsText.indexOf(name);
                String beforeTimeText = pacsText.substring(Math.max(timeIndex - 5, 0), timeIndex);
                String afterTimeText = pacsText.substring(timeIndex + name.length(), timeIndex + name.length() + 10);
                if (!beforeTimeText.contains("院") && !afterTimeText.contains("院")) {
                    status.set("-1");
                    return;
                }
            }
        }
    }
}